<?php
/* --------------------------------------------------------------
 GoogleAdWordsController.inc.php 2017-12-27
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2017 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

class GoogleAdWordsController extends AdminHttpViewController
{
	/**
	 * @var string
	 */
	protected $templatesBaseUrl;
	
	/**
	 * @var \LanguageTextManager
	 */
	protected $languageTextManager;
	
	/**
	 * @var \CI_DB_query_builder
	 */
	protected $db;
	
	
	/**
	 * Initialize the controller.
	 */
	public function init()
	{
		$this->templatesBaseUrl    = DIR_FS_CATALOG . 'GXModules/Gambio/GoogleAdWords/Admin/Html';
		$this->languageTextManager = MainFactory::create('LanguageTextManager', 'google_services_adwords',
		                                                 $_SESSION['languages_id']);
		$this->db                  = StaticGXCoreLoader::getDatabaseQueryBuilder();
	}
	
	
	public function actionDefault()
	{
		$title    = new NonEmptyStringType($this->languageTextManager->get_text('page_title'));
		$template = new ExistingFile(new NonEmptyStringType(DIR_FS_ADMIN
		                                                    . 'html/content/google_services/adwords/campaigns_overview.html'));
		
		$accountConnectionData = $this->_accountConnectionData();
		$jsBaseUrl             = 'html/assets/javascript/modules/google_services';
		
		$pageData = [
			'campaignsDateRanges' => $this->_campaignsDataRangeSelectionArray(),
			'pageToken'           => $_SESSION['coo_page_token']->generate_token(),
			'authSuccess'         => (string)$this->_getQueryParameter('success') === '1' ? : false,
			'show_account_form'   => gm_get_conf('GOOGLE_ADWORDS_CONNECTION_STATUS') === 'true' ? 'false' : 'true',
		];
		
		$data = MainFactory::create('KeyValueCollection', array_merge($pageData, $accountConnectionData));
		
		$assetsArray = [
			MainFactory::create('Asset', 'html/assets/styles/modules/google_services/campaigns_overview.css'),
			MainFactory::create('Asset', 'html/assets/styles/modules/google_services/partials/connect_account.css'),
			MainFactory::create('Asset', $jsBaseUrl . '/vendor/iframe_resizer.js'),
			MainFactory::create('Asset', $jsBaseUrl . '/extensions/resize_iframe.js'),
			MainFactory::create('Asset', 'google_adwords.lang.inc.php'),
		];
		
		$assets = MainFactory::create('AssetCollection', $assetsArray);
		
		return MainFactory::create('AdminLayoutHttpControllerResponse', $title, $template, $data, $assets);
	}
	
	
	private function _campaignsDataRangeSelectionArray()
	{
		return [
			'TODAY'               => [
				'selected' => false,
				'value'    => $this->languageTextManager->get_text('TODAY')
			],
			'YESTERDAY'           => [
				'selected' => false,
				'value'    => $this->languageTextManager->get_text('YESTERDAY')
			],
			'THIS_WEEK_SUN_TODAY' => [
				'selected' => false,
				'value'    => $this->languageTextManager->get_text('THIS_WEEK_SUN_TODAY')
			],
			'THIS_WEEK_MON_TODAY' => [
				'selected' => false,
				'value'    => $this->languageTextManager->get_text('THIS_WEEK_MON_TODAY')
			],
			'LAST_7_DAYS'         => [
				'selected' => false,
				'value'    => $this->languageTextManager->get_text('LAST_7_DAYS')
			],
			'LAST_WEEK_SUN_SAT'   => [
				'selected' => false,
				'value'    => $this->languageTextManager->get_text('LAST_WEEK_SUN_SAT')
			],
			'LAST_WEEK'           => [
				'selected' => false,
				'value'    => $this->languageTextManager->get_text('LAST_WEEK')
			],
			'LAST_BUSINESS_WEEK'  => [
				'selected' => false,
				'value'    => $this->languageTextManager->get_text('LAST_BUSINESS_WEEK')
			],
			'LAST_14_DAYS'        => [
				'selected' => false,
				'value'    => $this->languageTextManager->get_text('LAST_14_DAYS')
			],
			'THIS_MONTH'          => [
				'selected' => false,
				'value'    => $this->languageTextManager->get_text('THIS_MONTH')
			],
			'LAST_30_DAYS'        => [
				'selected' => false,
				'value'    => $this->languageTextManager->get_text('LAST_30_DAYS')
			],
			'LAST_MONTH'          => [
				'selected' => false,
				'value'    => $this->languageTextManager->get_text('LAST_MONTH')
			],
			''                    => [
				'selected' => true,
				'value'    => $this->languageTextManager->get_text('TOTAL_TIME')
			]
		];
	}
	
	
	private function _accountConnectionData()
	{
		return [
			'iFrameUrl' => gm_get_conf('GOOGLE_ADWORDS_APP_URL') . '#connect',
			'origin'    => HTTP_SERVER . DIR_WS_CATALOG,
			'error'     => (int)$this->_getQueryParameter('error'),
			'language'  => $_SESSION['language_code'],
		];
	}
}